@@ -1,7 +1,7 @@
 package Perinci::Sub::To::CLIDocData;
 
-our $DATE = '2014-12-09'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2015-03-19'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -147,6 +147,8 @@ _
     },
 };
 sub gen_cli_doc_data_from_meta {
+    require Getopt::Long::Negate::EN;
+
     my %args = @_;
 
     my $lang = $args{lang};
@@ -195,7 +197,7 @@ sub gen_cli_doc_data_from_meta {
             } else {
                 push @args, "[$arg]";
             }
-            push @args, "..." if $arg_spec->{greedy};
+            $args[-1] .= "..." if $arg_spec->{greedy};
             delete $args_prop{$arg};
         }
         unshift @args, "[options]" if keys(%args_prop) || keys(%$common_opts); # XXX translatable?
@@ -233,7 +235,7 @@ sub gen_cli_doc_data_from_meta {
         while (@k) {
             my $k = shift @k;
             my $ospec = $ospecs->{$k};
-            my $ok;
+            my $optkey;
 
             if ($ospec->{is_alias} || defined($ospec->{arg})) {
                 my $arg_spec;
@@ -246,7 +248,7 @@ sub gen_cli_doc_data_from_meta {
                     $arg_spec = $args_prop->{ $ospec->{arg} };
                     $alias_spec = $arg_spec->{cmdline_aliases}{$ospec->{alias}};
                     my $rimeta = rimeta($alias_spec);
-                    $ok = _fmt_opt($arg_spec, $ospec);
+                    $optkey = _fmt_opt($arg_spec, $ospec);
                     $opt = {
                         opt_parsed => $ospec->{parsed},
                         orig_opt => $k,
@@ -267,8 +269,8 @@ sub gen_cli_doc_data_from_meta {
                         orig_opt => $k,
                     };
 
-                    # for bool, only display either the positive (e.g. --bool) or
-                    # the negative (e.g. --nobool) depending on the default
+                    # for bool, only display either the positive (e.g. --bool)
+                    # or the negative (e.g. --nobool) depending on the default
                     if (defined($ospec->{is_neg})) {
                         my $default = $arg_spec->{default} //
                             $arg_spec->{schema}[1]{default};
@@ -311,7 +313,7 @@ sub gen_cli_doc_data_from_meta {
                         $j--;
                     }
 
-                    $ok = _fmt_opt($arg_spec, $ospec, @aliases);
+                    $optkey = _fmt_opt($arg_spec, $ospec, @aliases);
                 }
 
                 $opt->{arg_spec} = $arg_spec;
@@ -330,22 +332,38 @@ sub gen_cli_doc_data_from_meta {
                 _add_category_from_spec($opt, $arg_spec, "options", $has_cats);
                 _add_default_from_arg_spec($opt, $arg_spec);
 
-                $opts{$ok} = $opt;
+                $opts{$optkey} = $opt;
 
             } else {
                 # option from common_opts
 
-                $ok = _fmt_opt($common_opts, $ospec);
-                my $co = $common_opts->{$ospec->{common_opt}};
-                my $rimeta = rimeta($co);
-                $opts{$ok} = {
+                my $spec = $common_opts->{$ospec->{common_opt}};
+
+                # for bool, only display either the positive (e.g. --bool)
+                # or the negative (e.g. --nobool) depending on the default
+                my $show_neg = $ospec->{parsed}{is_neg} && $spec->{default};
+
+                local $ospec->{parsed}{opts} = do {
+                    # XXX check if it's single-letter, get first
+                    # non-single-letter
+                    my @opts = Getopt::Long::Negate::EN::negations_for_option(
+                        $ospec->{parsed}{opts}[0]);
+                    [ $opts[0] ];
+                } if $show_neg;
+
+                $optkey = _fmt_opt($spec, $ospec);
+                my $rimeta = rimeta($spec);
+                $opts{$optkey} = {
                     opt_parsed => $ospec->{parsed},
                     orig_opt => $k,
                     category => $has_cats ? "General options" : "Options", # XXX translatable?
-                    summary => $rimeta->langprop({lang=>$lang}, 'summary'),
-                    (schema => $co->{schema}) x !!$co->{schema},
+                    summary => $show_neg ?
+                        $rimeta->langprop({lang=>$lang}, 'summary.alt.bool.not') :
+                            $rimeta->langprop({lang=>$lang}, 'summary'),
+                    (schema => $spec->{schema}) x !!$spec->{schema},
                     description =>
                         $rimeta->langprop({lang=>$lang}, 'description'),
+                    (default => $spec->{default}) x !!(exists($spec->{default}) && !$show_neg),
                 };
 
             }
@@ -423,7 +441,7 @@ sub gen_cli_doc_data_from_meta {
 }
 
 1;
-# ABSTRACT: Generate data structure convenient for producing CLI help/usage
+# ABSTRACT: From Rinci function metadata, generate structure convenient for producing CLI documentation (help/usage/POD)
 
 __END__
 
@@ -433,11 +451,11 @@ __END__
 
 =head1 NAME
 
-Perinci::Sub::To::CLIDocData - Generate data structure convenient for producing CLI help/usage
+Perinci::Sub::To::CLIDocData - From Rinci function metadata, generate structure convenient for producing CLI documentation (help/usage/POD)
 
 =head1 VERSION
 
-This document describes version 0.14 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2014-12-09.
+This document describes version 0.15 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2015-03-19.
 
 =head1 SYNOPSIS
 
@@ -631,8 +649,6 @@ Pass per_arg_json=1 to Perinci::Sub::GetArgs::Argv.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -642,7 +658,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (hash)
+Return value:  (hash)
 
 =head1 SEE ALSO
 
@@ -672,7 +688,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
